@@ -17,7 +17,7 @@
 #include "subcircuit.h"
 #include "utils.h"
 #include "e-diode.h"
-#include "linkable.h"
+#include "linker.h"
 
 #define tr(str) QCoreApplication::translate("CircuitView",str)
 
@@ -38,13 +38,12 @@ CircuitView::CircuitView( QWidget *parent )
 
     //viewport()->setFixedSize( 3200, 2400 );
     bool scrollBars = MainWindow::self()->settings()->value( "Circuit/showScroll" ).toBool();
-    if( scrollBars )
-    {
+    if( scrollBars ){
         setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOn );
-        setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOn );
+        setVerticalScrollBarPolicy(   Qt::ScrollBarAlwaysOn );
     }else{
         setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
-        setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
+        setVerticalScrollBarPolicy(   Qt::ScrollBarAlwaysOff );
     }
     //setViewportUpdateMode( QGraphicsView::FullViewportUpdate );
     //setCacheMode( CacheBackground );
@@ -98,10 +97,13 @@ void CircuitView::dragEnterEvent( QDragEnterEvent* event )
             SubCircuit* subC = static_cast<SubCircuit*>( m_enterItem );
             if( subC->subcType() < Chip::Board ) subC->setLogicSymbol( true );
         }
-        m_enterItem->setPos( mapToScene( event->pos() ) );
-        m_circuit->addItem( m_enterItem );
-        m_circuit->compList()->insert( m_enterItem );
+        m_circuit->clearSelection();
+        m_circuit->addComponent( m_enterItem );
         m_circuit->saveCompChange( m_enterItem->getUid(), COMP_STATE_NEW, "" );
+
+        m_enterItem->setPos( mapToScene( event->pos() ) );
+        m_enterItem->setSelected( true );
+
         this->setFocus();
     }
 }
@@ -129,15 +131,14 @@ void CircuitView::mousePressEvent( QMouseEvent* event )
     if( event->button()   == Qt::LeftButton
      && event->modifiers() & Qt::ControlModifier
      && event->modifiers() & Qt::ShiftModifier
-     && !m_circuit->is_constarted() )
+     && !m_circuit->is_constarted() )                   // Prepare Copy by drag
     {
         QGraphicsItem* item = itemAt( event->pos() );
-        if( item )                                                  // Check if item exists before start drag:
-        {
+        if( item ){                                                 // Check if item exists before start drag:
             while ( item->parentItem() ) item = item->parentItem(); // Make sure the item deselected is the top graphic item.
 
             if( !item->isSelected() ) m_circuit->clearSelection();  // If the comp is not selected when drag starts, clear all the selections.
-            item->setSelected( false );
+            else                      item->setSelected( false );
             m_mousePressPos = event->pos();
             m_waitForDragStart = true;
         }
@@ -164,10 +165,10 @@ void CircuitView::mouseMoveEvent( QMouseEvent* event )
 
         if( event->modifiers() & Qt::ControlModifier
          && event->modifiers() & Qt::ShiftModifier
-         && !m_circuit->selectedItems().isEmpty() )
+         && !m_circuit->selectedItems().isEmpty() )     // Start Copy by drag
         {
             event->accept();
-            m_circuit->beginCircuitBatch();     // Add this to force paste() to not save changes
+            m_circuit->beginCircuitBatch();     // Do this to force paste() to not save changes
             m_circuit->copy( m_mousePressPos ); // Component move after paste() will save changes
             m_circuit->paste( event->pos() );   // paste() will call beginUndoStep()
         }
@@ -198,8 +199,8 @@ void CircuitView::overrideCursor( const QCursor &cursor )
 
 void CircuitView::contextMenuEvent( QContextMenuEvent* event )
 {
-    if( Linkable::m_selecComp ){ // Cancel link to components
-        Linkable::stopLinking();
+    if( Linker::m_selecComp ){ // Cancel link to components
+        Linker::stopLinking();
         return;
     }
     QGuiApplication::restoreOverrideCursor();
@@ -265,11 +266,9 @@ void CircuitView::zoomOne()
     m_scale = 1;
 }
 
-void CircuitView::importCirc()
-{ Circuit::self()->importCirc( m_eventpoint ); }
+void CircuitView::importCirc() { Circuit::self()->importCircuit(); }
 
-void CircuitView::slotPaste()
-{ m_circuit->paste( m_eventpoint ); }
+void CircuitView::slotPaste() { m_circuit->paste( m_eventpoint ); }
 
 void CircuitView::saveImage()
 {
