@@ -17,24 +17,26 @@
 
 #include "doubleprop.h"
 
-Component* Diac::construct( QObject* parent, QString type, QString id )
-{ return new Diac( parent, type, id ); }
+#define tr(str) simulideTr("Diac",str)
+
+Component* Diac::construct( QString type, QString id )
+{ return new Diac( type, id ); }
 
 LibraryItem* Diac::libraryItem()
 {
     return new LibraryItem(
-        QCoreApplication::translate( "Diac", "Diac" ),
+        tr("Diac"),
         "Rectifiers",
         "diac.png",
         "Diac",
         Diac::construct );
 }
 
-Diac::Diac( QObject* parent, QString type, QString id )
-     : Component( parent, type, id )
+Diac::Diac( QString type, QString id )
+     : Component( type, id )
      , eElement( id )
 {
-    m_area =  QRectF( -8, -16, 16, 32 );
+    m_area =  QRectF(-10,-16, 20, 32 );
     setLabelPos(-12,-30, 0 );
 
     m_resOn    = 500;
@@ -67,10 +69,17 @@ Diac::Diac( QObject* parent, QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new DoubProp<Diac>( "ResOn"   , tr("On Resistance")    ,"Ω", this, &Diac::resOn ,   &Diac::setResOn ),
-new DoubProp<Diac>( "ResOff"  , tr("Off Resistance")   ,"Ω", this, &Diac::resOff,   &Diac::setResOff ),
-new DoubProp<Diac>( "BrkVolt" , tr("Breakdown Voltage"),"V", this, &Diac::brkVolt,  &Diac::setBrkVolt ),
-new DoubProp<Diac>( "HoldCurr", tr("Hold Current")     ,"A", this, &Diac::holdCurr, &Diac::setHoldCurr )
+new DoubProp<Diac>("ResOn", tr("On Resistance"),"Ω"
+                  , this, &Diac::resOn , &Diac::setResOn ),
+
+new DoubProp<Diac>("ResOff", tr("Off Resistance"),"Ω"
+                  , this, &Diac::resOff,   &Diac::setResOff ),
+
+new DoubProp<Diac>("BrkVolt" , tr("Breakdown Voltage"),"V"
+                  , this, &Diac::brkVolt,  &Diac::setBrkVolt ),
+
+new DoubProp<Diac>("HoldCurr", tr("Hold Current"),"A"
+                  , this, &Diac::holdCurr, &Diac::setHoldCurr )
     },0} );
 }
 Diac::~Diac()
@@ -158,4 +167,6 @@ void Diac::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget*
 
     p->drawLine(-8,-16,-8, 16 );
     p->drawLine( 8,-16, 8, 16 );
+
+    Component::paintSelected( p );
 }
