@@ -3,6 +3,8 @@
  *                                                                         *
  ***( see copyright.txt file at root folder )*******************************/
 
+#include <QtMath>
+
 #include "csource.h"
 #include "simulator.h"
 #include "circuitwidget.h"
@@ -38,11 +40,13 @@ Csource::Csource( QString type, QString id )
     // Control Pins
     m_pin[0] = new Pin( 180, QPoint(-24,-8 ), id+"-cpPin", 0, this);
     m_pin[1] = new Pin( 180, QPoint(-24, 8 ), id+"-cmPin", 1, this);
-    m_pin[0]->setFontSize( 5 );
-    m_pin[0]->setLabelText("➕");
+    m_pin[0]->setFontSize( 9 );
+    m_pin[0]->setSpace( 1.7 );
+    m_pin[0]->setLabelText("+");
     m_pin[0]->setLabelColor( Qt::red );
-    m_pin[1]->setFontSize( 5 );
-    m_pin[1]->setLabelText("➖");
+    m_pin[1]->setFontSize( 9 );
+    m_pin[1]->setSpace( 1.7 );
+    m_pin[1]->setLabelText("–");  // U+2013
     m_pin[1]->setLabelColor( QColor( 0, 0, 0 ) );
     m_ePin[0] = m_pin[0];
     m_ePin[1] = m_pin[1];
@@ -86,6 +90,7 @@ void Csource::stamp()
     m_pin[2]->createCurrent();
     m_pin[3]->createCurrent();
 
+    m_lastCurr = 0;
     m_changed = true;
     updateStep();
 }
@@ -101,12 +106,12 @@ void Csource::updateStep()
     if( !m_changed ) return;
     m_changed = false;
 
-    udtProperties();
+    updtProperties();
 
-    m_pin[0]->setEnabled( m_controlPins );
-    m_pin[0]->setVisible( m_controlPins );
-    m_pin[1]->setEnabled( m_controlPins );
-    m_pin[1]->setVisible( m_controlPins );
+    m_pin[0]->setEnabled( m_controlPins && !m_linked );
+    m_pin[0]->setVisible( m_controlPins && !m_linked );
+    m_pin[1]->setEnabled( m_controlPins && !m_linked );
+    m_pin[1]->setVisible( m_controlPins && !m_linked );
 
     if( m_currControl )
     {
@@ -115,8 +120,8 @@ void Csource::updateStep()
         m_pin[1]->setLabelText( "" );
     }else{
         m_admit = cero_doub;
-        m_pin[0]->setLabelText("➕");
-        m_pin[1]->setLabelText("➖");
+        m_pin[0]->setLabelText("+");
+        m_pin[1]->setLabelText("–");  // U+2013
     }
     eResistor::stampAdmit();
 
@@ -136,8 +141,8 @@ void Csource::updateStep()
 
         if( m_currSource )
         {
-            m_pin[2]->stampCurrent( m_curr );
-            m_pin[3]->stampCurrent(-m_curr );
+            m_pin[2]->stampCurrent(-m_curr );
+            m_pin[3]->stampCurrent( m_curr );
         }else{
             m_pin[2]->stampCurrent( m_volt/cero_doub );
             m_pin[3]->stampCurrent(-m_volt/cero_doub );
@@ -154,18 +159,27 @@ void Csource::updateStep()
 void Csource::setVoltage( double v )
 {
     double curr = v;
+    //if( qFabs( curr - m_lastCurr ) < 1e-5 ) return;
+    m_lastCurr = curr;
 
-    if( m_currControl )              curr *= m_admit;
-    if( !m_currSource && curr != 0 ) curr /= cero_doub;
+    if( m_currSource   ) curr = -curr;      // Current source
+    else if( curr != 0 ) curr /= cero_doub; // Voltage source
+    if( m_currControl  ) curr *= m_admit;   // Current controlled
 
     curr *= m_gain;
     m_pin[2]->stampCurrent( curr );
     m_pin[3]->stampCurrent(-curr );
 }
 
+void Csource::setLinked( bool l )
+{
+    Component::setLinked( l );
+    setControlPins( m_controlPins );
+}
 
 void Csource::setLinkedValue( double v, int i )
 {
+    if( m_currControl ) v /= m_admit;
     setVoltage( v );
 }
 
@@ -208,12 +222,16 @@ void Csource::setCurrSource( bool c )
 
 void Csource::setControlPins( bool set )
 {
+    int length = (set || m_linked) ? 8 : 10;
+    m_pin[2]->setLength( length );
+    m_pin[3]->setLength( length );
+
     m_controlPins = set;
     m_changed = true;
     if( !Simulator::self()->isRunning() ) updateStep();
 }
 
-void Csource::udtProperties()
+void Csource::updtProperties()
 {
     if( !m_propDialog ) return;
     bool controlled = m_controlPins || m_linked; // Controlled by pins or Linked
@@ -222,31 +240,23 @@ void Csource::udtProperties()
     m_propDialog->showProp("Current"    , !controlled &&  m_currSource );
     m_propDialog->showProp("CurrControl",  controlled );
     m_propDialog->showProp("Gain"       ,  controlled );
+
+    m_propDialog->adjustWidgets();
 }
 
 void Csource::slotProperties()
 {
     Component::slotProperties();
-    udtProperties();
+    updtProperties();
 }
 
 void Csource::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
 {
     Component::paint( p, option, widget );
 
-    QPainterPath path;
-    QVector<QPointF> points;
-    points << QPointF(-8, 0 )
-           << QPointF( 0,-13 )
-           << QPointF( 8, 0 )
-           << QPointF( 0, 13 );
-
-    path.addPolygon( QPolygonF(points) );
-    path.closeSubpath();
-
     QPen pen = p->pen();
 
-    if( m_controlPins )
+    if( m_controlPins && !m_linked )
     {
         pen.setWidth(1);
         p->setPen(pen);
@@ -254,7 +264,23 @@ void Csource::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidge
     }
     pen.setWidth(2);
     p->setPen(pen);
-    p->drawPath( path );
+
+    if( !m_controlPins && !m_linked )
+    {
+        p->drawEllipse(-10,-10, 20, 20 );
+    }
+    else{
+        QPainterPath path;
+        QVector<QPointF> points;
+        points << QPointF(-8, 0 )
+               << QPointF( 0,-13 )
+               << QPointF( 8, 0 )
+               << QPointF( 0, 13 );
+
+        path.addPolygon( QPolygonF(points) );
+        path.closeSubpath();
+        p->drawPath( path );
+    }
 
     pen.setWidth(1);
     p->setPen(pen);
@@ -268,7 +294,7 @@ void Csource::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidge
         p->drawLine( 0,-6, 0,-2 );
         p->drawLine(-2, 4, 2, 4 );
     }
-    if( m_currControl && m_controlPins )
+    if( m_currControl && m_controlPins && !m_linked )
     {
         pen.setWidthF(0.6);
         p->setPen(pen);
@@ -276,4 +302,5 @@ void Csource::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidge
         p->drawLine(-13, 5,-12, 7 );
         p->drawLine(-11, 5,-12, 7 );
     }
+    Component::paintSelected( p );
 }
