@@ -14,6 +14,7 @@
 #include "textval.h"
 #include "enumval.h"
 #include "boolval.h"
+#include "colorval.h"
 #include "mainwindow.h"
 
 #include "comproperty.h"
@@ -26,9 +27,9 @@ PropDialog::PropDialog( QWidget* parent, QString help )
 
     m_component = NULL;
 
-    m_scale = MainWindow::self()->fontScale();
-    m_minW  = 280*m_scale;
-    m_minH  = 100*m_scale;
+    //m_scale = MainWindow::self()->fontScale();
+    //m_minW  = 280*m_scale;
+    //m_minH  = 100*m_scale;
 
     m_helpExpanded = false;
     helpText->setVisible( false );
@@ -38,6 +39,11 @@ PropDialog::PropDialog( QWidget* parent, QString help )
 
 void PropDialog::setComponent( CompBase* comp, bool isComp )
 {
+    QFontMetrics fm( labelLabel->font() );
+    m_scale = fm.width(" ")/2.0;
+    m_minW  = 265*m_scale;
+    m_minH  = 100*m_scale;
+
     QString title = isComp ? "Uid: " : "";
     this->setWindowTitle( title+comp->getUid() );
     type->setText( "Type: "+comp->itemType() );
@@ -52,7 +58,7 @@ void PropDialog::setComponent( CompBase* comp, bool isComp )
     m_component = comp;
     showButton->setChecked( comp->getPropStr("Show_id") == "true" );
 
-    int w=0, index=0;
+    int index=0;
     QList<propGroup>* groups = comp->properties();
 
     for( propGroup group : *groups )
@@ -60,7 +66,7 @@ void PropDialog::setComponent( CompBase* comp, bool isComp )
         if( group.flags & groupHidden ) continue;
 
         bool groupEnabled = true;
-        bool isMaincomp = comp->getPropStr("mainComp") == "true";
+        bool isMaincomp = comp->isHidden() && (comp->getPropStr("mainComp") == "true"); // main Compoenent & is in subcircuit
         if( isMaincomp && (group.flags & groupNoCopy) ) groupEnabled = false;
 
         QList<ComProperty*> propList = group.propList;
@@ -97,6 +103,7 @@ void PropDialog::setComponent( CompBase* comp, bool isComp )
                 PropVal* mp = NULL;
 
                 if     ( type == "double"  ) mp = new NumVal( this, comp, prop );
+                else if( type == "color"   ) mp = new ColorVal( this, comp, prop );
                 else if( type == "uint"    ) mp = new NumVal( this, comp, prop );
                 else if( type == "int"     ) mp = new NumVal( this, comp, prop );
                 else if( type == "string"  ) mp = new StrVal( this, comp, prop );
@@ -108,8 +115,6 @@ void PropDialog::setComponent( CompBase* comp, bool isComp )
                 if( !mp ) continue;
 
                 mp->setup( isComp );
-                //w = mp->width();
-                //mp->setMinimumWidth( w );
                 m_propList.append( mp );
                 groupWidget->layout()->addWidget( mp );
 
@@ -118,12 +123,11 @@ void PropDialog::setComponent( CompBase* comp, bool isComp )
 
                 mp->setEnabled( groupEnabled && propEnabled );
             }
-            groupWidget->setMinimumHeight( propList.size()*22*m_scale);
-            groupWidget->setMinimumWidth( 250*m_scale );
+            //groupWidget->setMinimumHeight( propList.size()*22*m_scale);
+            //groupWidget->setMinimumWidth( 250*m_scale );
             tabList->addTab( groupWidget, group.name );
     }   }
     if( tabList->count() == 0 ) tabList->setVisible( false ); // Hide tab widget if empty
-    adjustWidgets();
 }
 
 void PropDialog::showProp( QString name, bool show )
@@ -167,27 +171,32 @@ void PropDialog::on_helpButton_clicked()
 void PropDialog::adjustWidgets()
 {
     int h = 0;
-    int w = 0;
+    int w = m_minW;
     QWidget* widget = tabList->currentWidget();
-    if( widget ){
-        h = widget->minimumHeight()+100*m_scale;
-        w = widget->minimumWidth()+25*m_scale;
+    if( widget )
+    {
+        int count = 0;
+        for( int i=0; i<widget->layout()->count(); ++i )
+            if( !widget->layout()->itemAt(i)->widget()->isHidden() )
+                count++;
+
+        h = count*24*m_scale+90*m_scale;
     }
     if( h < m_minH ) h = m_minH;
-    if( w < m_minW ) w = m_minW;
 
     if( helpText->isVisible() )
     {
         helpText-> setFixedWidth( helpText->width() );
         w += helpText->width()+6;
     }
-    this->setMinimumHeight( h );
-    this->setMaximumHeight( h+100 );
+    this->setFixedHeight( h );
 
-    this->setMinimumWidth( w );
-    this->setMaximumWidth( w+150 );
+    //this->setMinimumWidth( w );
+    this->setMaximumWidth( w+100*m_scale );
 
     this->adjustSize();
+    this->setMaximumHeight( h+70*m_scale );
+
 }
 
 void PropDialog::updtValues()
