@@ -7,6 +7,7 @@
 
 #include "subcircuit.h"
 #include "itemlibrary.h"
+#include "mainwindow.h"
 #include "componentselector.h"
 #include "circuitwidget.h"
 #include "simulator.h"
@@ -16,7 +17,7 @@
 #include "e-node.h"
 #include "utils.h"
 #include "mcu.h"
-#include "linkable.h"
+#include "linker.h"
 
 #include "logicsubc.h"
 #include "board.h"
@@ -80,8 +81,7 @@ Component* SubCircuit::construct( QString type, QString id )
                 if( element.attribute("name") == name )
                 {
                     if( element.hasAttribute("folder") ) folder = element.attribute("folder");
-                    QFileInfo fi( dataFile );
-                    m_subcDir = fi.absolutePath()+"/"+folder+"/"+name;
+                    m_subcDir = MainWindow::self()->getDataFilePath( folder+"/"+name );
                     found = true;
                 }
                 if( found ) break;
@@ -99,6 +99,9 @@ Component* SubCircuit::construct( QString type, QString id )
     QString pkgFileLS = m_subcDir+"/"+name+"_LS.package";
     QString subcFile  = m_subcDir+"/"+name+".sim1";
 
+    // Package in sim file
+
+
     bool dip = QFile::exists( pkgeFile );
     bool ls  = QFile::exists( pkgFileLS );
 
@@ -141,7 +144,7 @@ Component* SubCircuit::construct( QString type, QString id )
     }
     if( m_error > 0 )
     {
-        Circuit::self()->compList()->remove( subcircuit );
+        Circuit::self()->compList()->removeOne( subcircuit );
         delete subcircuit;
         m_error = 0;
         return NULL;
@@ -162,17 +165,18 @@ LibraryItem* SubCircuit::libraryItem()
 SubCircuit::SubCircuit( QString type, QString id )
           : Chip( type, id )
 {
+    m_lsColor = QColor( 235, 240, 255 );
     m_icColor = QColor( 20, 30, 60 );
-    //m_mainComponent = NULL;
 }
 SubCircuit::~SubCircuit(){}
 
-void SubCircuit::loadSubCircuit( QString fileName )
+void SubCircuit::loadSubCircuit( QString file )
 {
-    QString doc = fileToString( fileName, "SubCircuit::loadSubCircuit" );
+    m_dataFile = file;
+    QString doc = fileToString( file, "SubCircuit::loadSubCircuit" );
 
     QString oldFilePath = Circuit::self()->getFilePath();
-    Circuit::self()->setFilePath( fileName );             // Path to find subcircuits/Scripted in our data folder
+    Circuit::self()->setFilePath( file );             // Path to find subcircuits/Scripted in our data folder
 
     QStringList graphProps;
     for( propGroup pg : m_propGroups ) // Create list of "Graphical" poperties (We don't need them)
@@ -186,7 +190,7 @@ void SubCircuit::loadSubCircuit( QString fileName )
     numId = numId.split("-").last();
     Circuit* circ = Circuit::self();
 
-    QList<Linkable*> linkList;   // Linked  Component list
+    QList<Linker*> linkList;   // Linked  Component list
 
     QVector<QStringRef> docLines = doc.splitRef("\n");
     for( QStringRef line : docLines )
@@ -269,17 +273,18 @@ void SubCircuit::loadSubCircuit( QString fileName )
                     if( m_subcType >= Board && comp->isGraphical() )
                     {
                         QPointF pos = comp->boardPos();
-                        if( pos == QPointF( -1e6, -1e6 ) ) // Don't show Components not placed
+                        if( pos == QPointF(-1e6,-1e6 ) ) // Don't show Components not placed
                         {
                             pos = QPointF( 0, 0 );
                             comp->setVisible( false );
                         }
                         comp->moveTo( pos );
                         comp->setRotation( comp->boardRot() );
+                        comp->setHflip( comp->boardHflip() );
+                        comp->setVflip( comp->boardVflip() );
                         if( !this->collidesWithItem( comp ) ) // Don't show Components out of Board
                         {
-                            pos = QPointF( 0, 0 );
-                            comp->moveTo( pos );
+                            comp->moveTo( QPointF( 0, 0 ) );
                             comp->setVisible( false );
                         }
                         comp->setHidden( true, true, true ); // Boards: hide non graphical
@@ -298,11 +303,10 @@ void SubCircuit::loadSubCircuit( QString fileName )
                     }
                     if( comp->isMainComp() ) m_mainComponents[uid] = comp; // This component will add it's Context Menu and properties
 
-                    m_compList.insert( comp );
+                    m_compList.append( comp );
 
-                    if( comp->m_linkable )
-                    {
-                        Linkable* l = dynamic_cast<Linkable*>(comp);
+                    if( comp->m_linker ){
+                        Linker* l = dynamic_cast<Linker*>(comp);
                         if( l->hasLinks() ) linkList.append( l );
                     }
 
@@ -315,8 +319,7 @@ void SubCircuit::loadSubCircuit( QString fileName )
                 }   }
                 else qDebug() << "SubCircuit:"<<m_name<<m_id<< "ERROR Creating Component: "<<type<<uid<<label;
     }   }   }
-    for( Linkable* l : linkList )
-        l->createLinks( &m_compList );
+    for( Linker* l : linkList ) l->createLinks( &m_compList );
 
     Circuit::self()->setFilePath( oldFilePath ); // Restore original filePath
 }
@@ -330,9 +333,8 @@ Pin* SubCircuit::addPin( QString id, QString type, QString label, int pos, int x
         QColor color = Qt::black;
         if( !m_isLS ) color = QColor( 250, 250, 200 );
 
-        Tunnel* tunnel = new Tunnel( "Tunnel", m_id+"-"+id );
-        Circuit::self()->compList()->remove( tunnel );
-        m_compList.insert( tunnel );
+        Tunnel* tunnel = new Tunnel("Tunnel", m_id+"-"+id );
+        m_compList.append( tunnel );
 
         QString pId = m_id+"-"+id;
         tunnel->setParentItem( this );
@@ -345,11 +347,9 @@ Pin* SubCircuit::addPin( QString id, QString type, QString label, int pos, int x
         m_pinTunnels.insert( pId, tunnel );
 
         Pin* pin = tunnel->getPin();
-        /// pin->setObjectName( pId );
         pin->setId( pId );
         pin->setInverted( type == "inverted" || type == "inv" );
         addSignalPin( pin );
-        /// connect( this, &SubCircuit::moved, pin, &Pin::isMoved, Qt::UniqueConnection );
 
         tunnel->setRotated( angle >= 180 );      // Our Pins at left side
         if     ( angle == 180) tunnel->setRotation( 0 );
@@ -433,7 +433,7 @@ void SubCircuit::setLogicSymbol( bool ls )
 
 Component* SubCircuit::getMainComp( QString name )
 {
-    if( name.isEmpty() ) return m_mainComponents.value( m_mainComponents.keys().first() );
+    if( name.isEmpty() && m_mainComponents.size() ) return m_mainComponents.value( m_mainComponents.keys().first() );
     return m_mainComponents.value(name);
 }
 
@@ -451,8 +451,8 @@ void SubCircuit::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu
     for( Component* mainComp : m_mainComponents.values() )
     {
         QString compType = mainComp->getUid();
-        int pos = compType.indexOf("_")+1;
-        int len = compType.lastIndexOf("-")-pos;
+        int pos  = compType.indexOf("_")+1;
+        int len  = compType.lastIndexOf("-")-pos;
         compType = compType.mid( pos, len );
 
         QMenu* submenu = menu->addMenu( QIcon(":/subc.png"), compType );
