@@ -8,10 +8,13 @@
 #include "simulator.h"
 #include "circuit.h"
 #include "circuitwidget.h"
+#include "propdialog.h"
+#include "iopin.h"
 #include "utils.h"
 
 #include "stringprop.h"
 #include "doubleprop.h"
+#include "boolprop.h"
 #include "intprop.h"
 
 #define tr(str) simulideTr("PlotBase",str)
@@ -23,6 +26,9 @@ PlotBase::PlotBase( QString type, QString id )
     m_graphical = true;
     m_bufferSize = 600000;
 
+    m_connectGnd = true;
+    m_inputAdmit = 1e-7;
+
     m_color[0] = QColor( 240, 240, 100 );
     m_color[1] = QColor( 220, 220, 255 );
     m_color[2] = QColor( 255, 210, 90  );
@@ -32,19 +38,19 @@ PlotBase::PlotBase( QString type, QString id )
     m_baSizeX = 135;
     m_baSizeY = 135;
 
-    int r;
+    //int r;
     m_pauseFunc = NULL;
     m_aEngine->RegisterObjectType("PlotBase",0, asOBJ_REF | asOBJ_NOCOUNT );
     m_aEngine->RegisterGlobalProperty("PlotBase pb", this );
-    r = m_aEngine->RegisterObjectProperty("PlotBase", "bool m_pause", asOFFSET(PlotBase,m_pause)); //assert( r >= 0 );
-    r = m_aEngine->RegisterObjectProperty("PlotBase", "int ch1", asOFFSET(PlotBase,m_condCh1)); //assert( r >= 0 );
-    r = m_aEngine->RegisterObjectProperty("PlotBase", "int ch2", asOFFSET(PlotBase,m_condCh2)); //assert( r >= 0 );
-    r = m_aEngine->RegisterObjectProperty("PlotBase", "int ch3", asOFFSET(PlotBase,m_condCh3)); //assert( r >= 0 );
-    r = m_aEngine->RegisterObjectProperty("PlotBase", "int ch4", asOFFSET(PlotBase,m_condCh4)); //assert( r >= 0 );
-    r = m_aEngine->RegisterObjectProperty("PlotBase", "int ch5", asOFFSET(PlotBase,m_condCh5)); //assert( r >= 0 );
-    r = m_aEngine->RegisterObjectProperty("PlotBase", "int ch6", asOFFSET(PlotBase,m_condCh6)); //assert( r >= 0 );
-    r = m_aEngine->RegisterObjectProperty("PlotBase", "int ch7", asOFFSET(PlotBase,m_condCh7)); //assert( r >= 0 );
-    r = m_aEngine->RegisterObjectProperty("PlotBase", "int ch8", asOFFSET(PlotBase,m_condCh8)); //assert( r >= 0 );
+    /*r = */m_aEngine->RegisterObjectProperty("PlotBase", "bool m_pause", asOFFSET(PlotBase,m_pause)); //assert( r >= 0 );
+    /*r = */m_aEngine->RegisterObjectProperty("PlotBase", "int ch1", asOFFSET(PlotBase,m_condCh1)); //assert( r >= 0 );
+    /*r = */m_aEngine->RegisterObjectProperty("PlotBase", "int ch2", asOFFSET(PlotBase,m_condCh2)); //assert( r >= 0 );
+    /*r = */m_aEngine->RegisterObjectProperty("PlotBase", "int ch3", asOFFSET(PlotBase,m_condCh3)); //assert( r >= 0 );
+    /*r = */m_aEngine->RegisterObjectProperty("PlotBase", "int ch4", asOFFSET(PlotBase,m_condCh4)); //assert( r >= 0 );
+    /*r = */m_aEngine->RegisterObjectProperty("PlotBase", "int ch5", asOFFSET(PlotBase,m_condCh5)); //assert( r >= 0 );
+    /*r = */m_aEngine->RegisterObjectProperty("PlotBase", "int ch6", asOFFSET(PlotBase,m_condCh6)); //assert( r >= 0 );
+    /*r = */m_aEngine->RegisterObjectProperty("PlotBase", "int ch7", asOFFSET(PlotBase,m_condCh7)); //assert( r >= 0 );
+    /*r = */m_aEngine->RegisterObjectProperty("PlotBase", "int ch8", asOFFSET(PlotBase,m_condCh8)); //assert( r >= 0 );
 
     QString n;
     for( int i=1; i<9; ++i ) // Condition simple to script: ch1l to (ch1==1)
@@ -62,17 +68,19 @@ PlotBase::PlotBase( QString type, QString id )
     m_exportFile = changeExt( Circuit::self()->getFilePath(), "_"+id+".vcd" );
 
     addPropGroup( { tr("Main"), {
-new IntProp<PlotBase>( "Basic_X"    ,tr("Screen Size X"),tr("_Pixels"), this, &PlotBase::baSizeX,    &PlotBase::setBaSizeX   ,0, "uint" ),
-new IntProp<PlotBase>( "Basic_Y"    ,tr("Screen Size Y"),tr("_Pixels"), this, &PlotBase::baSizeY,    &PlotBase::setBaSizeY   ,0, "uint" ),
-new IntProp<PlotBase>( "BufferSize" ,tr("Buffer Size")  ,tr("Samples"), this, &PlotBase::bufferSize, &PlotBase::setBufferSize,0,"uint" ),
+new IntProp <PlotBase>("Basic_X"   ,tr("Screen Width") ,tr("_Px"), this, &PlotBase::baSizeX,    &PlotBase::setBaSizeX   ,0,"uint" ),
+new IntProp <PlotBase>("Basic_Y"   ,tr("Screen Height"),tr("_Px"), this, &PlotBase::baSizeY,    &PlotBase::setBaSizeY   ,0,"uint" ),
+new IntProp <PlotBase>("BufferSize",tr("Buffer Size")  ,""       , this, &PlotBase::bufferSize, &PlotBase::setBufferSize,0,"uint" ),
+new BoolProp<PlotBase>("connectGnd",tr("Connect to ground"),""   , this, &PlotBase::connectGnd, &PlotBase::setConnectGnd,0 ),
+new DoubProp<PlotBase>("InputAdmit",tr("Impedance")    ,"Ω"      , this, &PlotBase::inputImped, &PlotBase::setInputImped )
     }, groupNoCopy} );
     addPropGroup( {"Hidden", {
-new StrProp<PlotBase>( "TimDiv"  ,"","", this, &PlotBase::timDiv,  &PlotBase::setTimDiv ),
-new StrProp<PlotBase>( "TimPos"  ,"","", this, &PlotBase::timPos,  &PlotBase::setTimPos ),
-new StrProp<PlotBase>( "VolDiv" ,"", "", this, &PlotBase::volDiv,  &PlotBase::setVolDiv ),
-new StrProp<PlotBase>( "Conds"   ,"","", this, &PlotBase::conds,   &PlotBase::setConds ),
-new StrProp<PlotBase>( "Tunnels" ,"","", this, &PlotBase::tunnels, &PlotBase::setTunnels ),
-new IntProp<PlotBase>( "Trigger" ,"","", this, &PlotBase::trigger, &PlotBase::setTrigger ),
+new StrProp<PlotBase>("TimDiv" ,"","", this, &PlotBase::timDiv,  &PlotBase::setTimDiv ),
+new StrProp<PlotBase>("TimPos" ,"","", this, &PlotBase::timPos,  &PlotBase::setTimPos ),
+new StrProp<PlotBase>("VolDiv" ,"","", this, &PlotBase::volDiv,  &PlotBase::setVolDiv ),
+new StrProp<PlotBase>("Conds"  ,"","", this, &PlotBase::conds,   &PlotBase::setConds ),
+new StrProp<PlotBase>("Tunnels","","", this, &PlotBase::tunnels, &PlotBase::setTunnels ),
+new IntProp<PlotBase>("Trigger","","", this, &PlotBase::trigger, &PlotBase::setTrigger ),
     }, groupHidden } );
 }
 PlotBase::~PlotBase()
@@ -82,9 +90,9 @@ PlotBase::~PlotBase()
 
 bool PlotBase::setPropStr( QString prop, QString val )
 {
-    if     ( prop =="hTick" ) setTimeDiv( val.toLongLong()*1e3 ); // Old: TODELETE
-    else if( prop =="vTick" ) setVolDiv( val );
-    else if( prop =="TimePos" ) setTimPos( val+"000" );
+    if     ( prop =="hTick"  ) setTimeDiv( val.toLongLong()*1e3 ); // Old: TODELETE
+    else if( prop =="vTick"  ) setVolDiv( val );
+    else if( prop =="TimePos") setTimPos( val+"000" );
     else return Component::setPropStr( prop, val );
     return true;
 }
@@ -115,6 +123,23 @@ void PlotBase::setBufferSize( int bs )
     }
 }
 
+void PlotBase::setConnectGnd( bool c )
+{
+    if( m_connectGnd == c ) return;
+    m_connectGnd = c;
+    updtProperties();
+    m_changed = true;
+}
+
+void PlotBase::setInputImped( double a )
+{
+    double admit = 1/a;
+    if( m_inputAdmit == admit ) return;
+    if( admit  < 0 ) return;
+    m_inputAdmit = admit;
+    m_changed = true;
+}
+
 QString PlotBase::timDiv()
 {
     return QString::number( m_timeDiv );
@@ -157,7 +182,7 @@ void PlotBase::updateConds( QString conds )
         conds.replace( "ch"+n+"f", m_condTo.value("ch"+n+"f") );
     }
     m_script = "void pause() { pb.m_pause = "+conds+";}";
-    qDebug() << m_script <<endl;
+    /// qDebug() << m_script <<endl;
     int r = compileScript();
     if( r < 0 ) { qDebug() << "PlotBase::updateConds Failed to compile expression:"<<conds; return; }
 
@@ -205,6 +230,19 @@ void PlotBase::conditonMet( int ch, cond_t cond )
     }*/
 }
 
+void PlotBase::slotProperties()
+{
+    Component::slotProperties();
+    updtProperties();
+}
+
+void PlotBase::updtProperties()
+{
+    if( !m_propDialog ) return;
+    m_propDialog->showProp("InputAdmit", m_connectGnd );
+    m_propDialog->adjustWidgets();
+}
+
 void PlotBase::remove()
 {
     if( m_expand ) expand( false );
@@ -224,4 +262,6 @@ void PlotBase::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidg
     pen.setWidth( 0 );
     pen.setColor( Qt::white );
     p->setPen(pen);
+
+    Component::paintSelected( p );
 }
