@@ -7,7 +7,7 @@
 #include "mainwindow.h"
 #include "mcu.h"
 
-InfoWidget*  InfoWidget::m_pSelf = nullptr;
+InfoWidget* InfoWidget::m_pSelf = nullptr;
 
 InfoWidget::InfoWidget( QWidget* parent )
           : QWidget( parent )
@@ -15,7 +15,7 @@ InfoWidget::InfoWidget( QWidget* parent )
     setupUi( this );
     m_pSelf = this;
 
-    QFont font( "Ubuntu", 10, QFont::Bold );
+    QFont font( MainWindow::self()->defaultFontName() , 10, QFont::Bold );
     double fontScale = MainWindow::self()->fontScale();
     font.setPixelSize( 12*fontScale );
 
@@ -29,9 +29,16 @@ InfoWidget::InfoWidget( QWidget* parent )
     simLoadVal->setFont( font );
     guiLoadLabel->setFont( font );
     guiLoadVal->setFont( font );
+    overLoadLabel->setFont( font );
+    overLoadVal->setFont( font );
+    fpsLabel->setFont( font );
+    fpsVal->setFont( font );
     mainMcuLabel->setFont( font );
     mainMcu->setFont( font );
     mainMcuName->setFont( font );
+
+    overLoadLabel->setVisible( false );
+    overLoadVal->setVisible( false );
 }
 
 void InfoWidget::setTargetSpeed( double s )
@@ -40,7 +47,11 @@ void InfoWidget::setTargetSpeed( double s )
     if( s < 100 ) speed = "0"+speed;
     if( s < 10 )  speed = "0"+speed;
     targetSpeed->setText( speed );
+    updtMcu();
+}
 
+void InfoWidget::updtMcu()
+{
     if( Mcu::self() )
     {
         QString device = Mcu::self()->device();
@@ -49,7 +60,7 @@ void InfoWidget::setTargetSpeed( double s )
 
         QString name;
         Mcu* mcu = Mcu::self();
-        if( mcu->isMainComp() )
+        if( mcu->isMainComp() && mcu->parentItem() )
         {
             Component* comp = static_cast<Component*>( mcu->parentItem() );
             name = comp->idLabel();
@@ -60,16 +71,14 @@ void InfoWidget::setTargetSpeed( double s )
         mainMcu->setText( "---" );
         mainMcuName->setText( "---" );
     }
+    mainMcuLabel->setVisible( Mcu::self() );
+    mainMcu->setVisible( Mcu::self() );
+    mainMcuName->setVisible( Mcu::self() );
 }
 
-void InfoWidget::setRate( double rate, double simLoad, double guiLoad )
+void InfoWidget::setRate( double rate, double simLoad, double guiLoad, int fps )
 {
-    if( Mcu::self() )
-    {
-        QString device = Mcu::self()->device();
-        QString freq = QString::number( Mcu::self()->freq()*1e-6 );
-        mainMcu->setText( device+" at "+freq+" MHz" );
-    }
+    updtMcu();
     if( rate < 0 )
     {
         if( rate == -1 ) realSpeed->setText( tr("Speed: Debugger") );
@@ -78,16 +87,35 @@ void InfoWidget::setRate( double rate, double simLoad, double guiLoad )
         //if( (load > 150) || (load < 0) ) load = 0;
         double speed = rate/100;
         QString Srate = QString::number( speed,'f', 2 );
-        if( speed < 100 ) Srate = "0"+Srate;
-        if( speed < 10 )  Srate = "0"+Srate;
+        while( Srate.size() < 6 ) Srate = "0"+Srate;
+
+        if( simLoad > 101 )
+        {
+            int overLoad = simLoad-100;
+            simLoad = 100;
+
+            QString Oload = QString::number( overLoad,'f', 2 );
+            while( Oload.size() < 6 ) Oload = "0"+Oload;
+
+            overLoadVal->setText( Oload+" %    ");
+            overLoadLabel->setVisible( true );
+            overLoadVal->setVisible( true );
+        }else{
+            overLoadLabel->setVisible( false );
+            overLoadVal->setVisible( false );
+        }
         QString Sload = QString::number( simLoad,'f', 2 );
         while( Sload.size() < 6 ) Sload = "0"+Sload;
+
         QString Gload = QString::number( guiLoad,'f', 2 );
         while( Gload.size() < 6 ) Gload = "0"+Gload;
 
+        QString FPS = QString::number( fps );
+
         realSpeed->setText( Srate+" %" );
         simLoadVal->setText( Sload+" %    ");
         guiLoadVal->setText( Gload+" %    ");
+        fpsVal->setText( FPS );
 }   }
 
 void InfoWidget::setCircTime( uint64_t tStep )
